@@ -1,6 +1,6 @@
 #include <string.h>
 #include <Python.h>
-#include "sass_context.h"
+#include <sass/context.h>
 
 #if PY_MAJOR_VERSION >= 3
 #define PySass_IF_PY3(three, two) (three)
@@ -278,6 +278,7 @@ static union Sass_Value* _exception_to_sass_error() {
     PyObject* evalue = NULL;
     PyObject* etb = NULL;
     PyErr_Fetch(&etype, &evalue, &etb);
+    PyErr_NormalizeException(&etype, &evalue, &etb);
     {
         PyObject* traceback_mod = PyImport_ImportModule("traceback");
         PyObject* traceback_parts = PyObject_CallMethod(
@@ -296,6 +297,9 @@ static union Sass_Value* _exception_to_sass_error() {
         Py_DECREF(result);
         Py_DECREF(bytes);
     }
+    Py_DECREF(etype);
+    Py_DECREF(evalue);
+    Py_DECREF(etb);
     return retv;
 }
 
@@ -352,7 +356,7 @@ static union Sass_Value* _to_sass_value(PyObject* value) {
 static union Sass_Value* _call_py_f(
         const union Sass_Value* sass_args,
         Sass_Function_Entry cb,
-        struct Sass_Options* opts
+        struct Sass_Compiler* compiler
 ) {
     size_t i;
     PyObject* pyfunc = (PyObject*)sass_function_get_cookie(cb);
@@ -408,15 +412,15 @@ PySass_compile_string(PyObject *self, PyObject *args) {
     char *string, *include_paths;
     const char *error_message, *output_string;
     Sass_Output_Style output_style;
-    int source_comments, error_status, precision;
+    int source_comments, error_status, precision, indented;
     PyObject *custom_functions;
     PyObject *result;
 
     if (!PyArg_ParseTuple(args,
-                          PySass_IF_PY3("yiiyiO", "siisiO"),
+                          PySass_IF_PY3("yiiyiOi", "siisiOi"),
                           &string, &output_style, &source_comments,
                           &include_paths, &precision,
-                          &custom_functions)) {
+                          &custom_functions, &indented)) {
         return NULL;
     }
 
@@ -426,6 +430,7 @@ PySass_compile_string(PyObject *self, PyObject *args) {
     sass_option_set_source_comments(options, source_comments);
     sass_option_set_include_path(options, include_paths);
     sass_option_set_precision(options, precision);
+    sass_option_set_is_indented_syntax_src(options, indented);
     _add_custom_functions(options, custom_functions);
 
     sass_compile_data_context(context);
