@@ -11,8 +11,10 @@ type.
 
 """
 from __future__ import absolute_import
+
 import collections
 import inspect
+from io import open
 import os
 import os.path
 import re
@@ -26,7 +28,7 @@ from _sass import OUTPUT_STYLES, compile_filename, compile_string
 __all__ = ('MODES', 'OUTPUT_STYLES', 'SOURCE_COMMENTS', 'CompileError',
            'SassColor', 'SassError', 'SassFunction', 'SassList', 'SassMap',
            'SassNumber', 'SassWarning', 'and_join', 'compile')
-__version__ = '0.8.2'
+__version__ = '0.9.3'
 
 
 #: (:class:`collections.Mapping`) The dictionary of output styles.
@@ -150,13 +152,14 @@ def compile_dirname(
     for dirpath, _, filenames in os.walk(search_path):
         filenames = [
             filename for filename in filenames
-            if filename.endswith('.scss') and not filename.startswith('_')
+            if filename.endswith(('.scss', '.sass'))
+            and not filename.startswith('_')
         ]
         for filename in filenames:
             input_filename = os.path.join(dirpath, filename)
             relpath_to_file = os.path.relpath(input_filename, search_path)
             output_filename = os.path.join(output_path, relpath_to_file)
-            output_filename = re.sub('.scss$', '.css', output_filename)
+            output_filename = re.sub('.s[ac]ss$', '.css', output_filename)
             input_filename = input_filename.encode(fs_encoding)
             s, v, _ = compile_filename(
                 input_filename, output_style, source_comments, include_paths,
@@ -165,7 +168,8 @@ def compile_dirname(
             if s:
                 v = v.decode('UTF-8')
                 mkdirp(os.path.dirname(output_filename))
-                with open(output_filename, 'w') as output_file:
+                with open(output_filename, 'w',
+                          encoding="UTF-8") as output_file:
                     output_file.write(v)
             else:
                 return False, v
@@ -201,6 +205,9 @@ def compile(**kwargs):
     :type custom_functions: :class:`collections.Set`,
                             :class:`collections.Sequence`,
                             :class:`collections.Mapping`
+    :param indented: optional declaration that the string is SASS, not SCSS
+                     formatted. :const:`False` by default
+    :type indented: :class:`bool`
     :returns: the compiled CSS string
     :rtype: :class:`str`
     :raises sass.CompileError: when it fails for any reason
@@ -429,7 +436,7 @@ def compile(**kwargs):
     elif isinstance(custom_functions, (collections.Set, collections.Sequence)):
         custom_functions = [
             func if isinstance(func, SassFunction)
-                 else SassFunction.from_named_function(func)
+            else SassFunction.from_named_function(func)
             for func in custom_functions
         ]
     else:
@@ -445,9 +452,13 @@ def compile(**kwargs):
         string = kwargs.pop('string')
         if isinstance(string, text_type):
             string = string.encode('utf-8')
+        indented = kwargs.pop('indented', False)
+        if not isinstance(indented, bool):
+            raise TypeError('indented must be bool, not ' +
+                            repr(source_comments))
         s, v = compile_string(
             string, output_style, source_comments, include_paths, precision,
-            custom_functions,
+            custom_functions, indented
         )
         if s:
             return v.decode('utf-8')
