@@ -5,6 +5,7 @@ import collections
 import contextlib
 import glob
 import json
+import io
 import os
 import os.path
 import re
@@ -55,9 +56,11 @@ A_EXPECTED_MAP = {
     'version': 3,
     'file': 'test/a.css',
     'sources': ['test/a.scss'],
-    'sourcesContent': [],
     'names': [],
-    'mappings': ';AAKA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAM,GAGpB;;EAEJ,IAAI,CAAC,CAAC,CAAJ;IACA,KAAK,EAAE,IAAK,GADX',
+    'mappings': (
+        ';AAKA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAM,GAQzB;;EALD,IAAI,CAEF,CAAC,'
+        'CAAC;IACA,KAAK,EAAE,IAAK,GACb'
+    ),
 }
 
 B_EXPECTED_CSS = '''\
@@ -253,6 +256,11 @@ a {
         self.assertRaises(TypeError, sass.compile, string=1234)
         self.assertRaises(TypeError, sass.compile, string=[])
 
+    def test_compile_string_sass_style(self):
+        actual = sass.compile(string='a\n\tb\n\t\tcolor: blue;',
+                              indented=True)
+        assert actual == 'a b {\n  color: blue; }\n'
+
     def test_compile_string_deprecated_source_comments_line_numbers(self):
         source = '''a {
             b { color: blue; }
@@ -455,9 +463,10 @@ class ManifestTestCase(BaseTestCase):
                     'version': 3,
                     'file': '../test/b.css',
                     'sources': ['../test/b.scss'],
-                    'sourcesContent': [],
                     'names': [],
-                    'mappings': ';AACE,CAAC,CAAC,CAAC,CAAD;EACA,SAAS,EAAE,IAAK,GADf',
+                    'mappings': (
+                        ';AAAA,CAAC,CACC,CAAC,CAAC;EACA,SAAS,EAAE,IAAK,GACjB'
+                    ),
                 },
                 os.path.join(d, 'css', 'b.scss.css.map')
             )
@@ -473,9 +482,11 @@ class ManifestTestCase(BaseTestCase):
                     'version': 3,
                     'file': '../test/d.css',
                     'sources': ['../test/d.scss'],
-                    'sourcesContent': [],
                     'names': [],
-                    'mappings': ';;AAKA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAM,GAGpB;;EAEJ,IAAI,CAAC,CAAC,CAAJ;IACA,IAAI,EAAE,0BAA2B,GADhC',
+                    'mappings': (
+                        ';;AAKA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAM,GAQzB;;EALD,'
+                        'IAAI,CAEF,CAAC,CAAC;IACA,IAAI,EAAE,0BAA2B,GAClC'
+                    ),
                 },
                 os.path.join(d, 'css', 'd.scss.css.map')
             )
@@ -581,7 +592,7 @@ class SasscTestCase(BaseTestCase):
         self.assertEqual(2, exit_code)
         err = self.err.getvalue()
         assert err.strip().endswith('error: too few arguments'), \
-               'actual error message is: ' + repr(err)
+            'actual error message is: ' + repr(err)
         self.assertEqual('', self.out.getvalue())
 
     def test_three_args(self):
@@ -592,7 +603,7 @@ class SasscTestCase(BaseTestCase):
         self.assertEqual(2, exit_code)
         err = self.err.getvalue()
         assert err.strip().endswith('error: too many arguments'), \
-               'actual error message is: ' + repr(err)
+            'actual error message is: ' + repr(err)
         self.assertEqual('', self.out.getvalue())
 
     def test_sassc_stdout(self):
@@ -639,7 +650,7 @@ class SasscTestCase(BaseTestCase):
         assert err.strip().endswith('error: -m/-g/--sourcemap requires '
                                     'the second argument, the output css '
                                     'filename.'), \
-               'actual error message is: ' + repr(err)
+            'actual error message is: ' + repr(err)
         self.assertEqual('', self.out.getvalue())
 
     def test_sassc_sourcemap(self):
@@ -693,8 +704,10 @@ class CompileDirectoriesTest(unittest.TestCase):
             input_dir = os.path.join(tmpdir, 'input')
             output_dir = os.path.join(tmpdir, 'output')
             os.makedirs(os.path.join(input_dir, 'foo'))
-            write_file(os.path.join(input_dir, 'f1.scss'), 'a { b { width: 100%; } }')
-            write_file(os.path.join(input_dir, 'foo/f2.scss'), 'foo { width: 100%; }')
+            write_file(os.path.join(input_dir, 'f1.scss'),
+                       'a { b { width: 100%; } }')
+            write_file(os.path.join(input_dir, 'foo/f2.scss'),
+                       'foo { width: 100%; }')
             # Make sure we don't compile non-scss files
             write_file(os.path.join(input_dir, 'baz.txt'), 'Hello der')
 
@@ -710,6 +723,21 @@ class CompileDirectoriesTest(unittest.TestCase):
             self.assertEqual(contentsf1, 'a b {\n  width: 100%; }\n')
             self.assertEqual(contentsf2, 'foo {\n  width: 100%; }\n')
 
+    def test_compile_directories_unicode(self):
+        with tempdir() as tmpdir:
+            input_dir = os.path.join(tmpdir, 'input')
+            output_dir = os.path.join(tmpdir, 'output')
+            os.makedirs(input_dir)
+            with io.open(
+                os.path.join(input_dir, 'test.scss'), 'w', encoding='UTF-8',
+            ) as f:
+                f.write(u'a { content: "☃"; }')
+            # Raised a UnicodeEncodeError in py2 before #82 (issue #72)
+            # Also raised a UnicodeEncodeError in py3 if the default encoding
+            # couldn't represent it (such as cp1252 on windows)
+            sass.compile(dirname=(input_dir, output_dir))
+            assert os.path.exists(os.path.join(output_dir, 'test.css'))
+
     def test_ignores_underscored_files(self):
         with tempdir() as tmpdir:
             input_dir = os.path.join(tmpdir, 'input')
@@ -728,16 +756,19 @@ class CompileDirectoriesTest(unittest.TestCase):
             write_file(os.path.join(input_dir, 'bad.scss'), 'a {')
 
             try:
-                sass.compile(dirname=(input_dir, os.path.join(tmpdir, 'output')))
+                sass.compile(
+                    dirname=(input_dir, os.path.join(tmpdir, 'output'))
+                )
                 assert False, 'Expected to raise'
             except sass.CompileError as e:
                 msg, = e.args
                 assert msg.decode('UTF-8').startswith(
-                    'Error: invalid property name'
+                    'Error: Invalid CSS after '
                 ), msg
                 return
             except Exception as e:
-                assert False, 'Expected to raise CompileError but got {0!r}'.format(e)
+                assert False, \
+                    'Expected to raise CompileError but got {0!r}'.format(e)
 
 
 class SassFunctionTest(unittest.TestCase):
@@ -829,7 +860,7 @@ class SassTypesTest(unittest.TestCase):
         warn = sass.SassWarning(u'error msg')
         assert type(warn.msg) is text_type, type(warn.msg)
 
-    def test_sass_warning_no_conversion(self):
+    def test_sass_warning_no_conversion_bytes_message(self):
         warn = sass.SassWarning(b'error msg')
         assert type(warn.msg) is text_type, type(warn.msg)
 
@@ -853,6 +884,7 @@ def returns_warning():
 def returns_error():
     return sass.SassError('This is an error')
 
+
 def returns_unknown():
     """Tuples are a not-supported type."""
     return 1, 2, 3
@@ -907,7 +939,7 @@ def identity(x):
     in C land
 
     """
-    import sys
+    import sys  # noqa
     return x
 
 
